# ============================================================================
# Name        : main.py
# Author      : nir
# Version     : 0.1
# Description : Python Hildon Hello World
# ============================================================================


import datetime
import gtk 
import hildon
from accelerometer import Accelerometer
import time
import pygame
import dbus
from sms_manager import Messager    
    
class Cap(hildon.Program):

    def hideWindow(self):        
        self.STAGE = 1
        self.window.hide()
        if (gtk.init_check()):
            gtk.main_quit()
        self.sound1.stop()
        self.sound2.stop()
        self.sound3.stop()
        self.sound4.stop()
    def showWindow(self):
        self.STAGE = 2
        self.window.show_all()
        self.time_stamp = time.time()
        self.sound_click.play()
        self.PlayAlarm()
    def clickedOk(self, widget, data):
        self.hideWindow()
        self.sound_click.play()
    def clickedHelp(self, widget, data):
        if (self.STAGE != 5):
            self.STAGE = self.STAGE +1
        self.PlayAlarm()
        self.time_stamp = time.time()
    def createOkButton(self):
        self.buttonOk = hildon.Button(gtk.HILDON_SIZE_AUTO,  hildon.BUTTON_ARRANGEMENT_VERTICAL)        
        self.buttonOk.connect("clicked", self.clickedOk, self)
        self.box.add(self.buttonOk)
        self.buttonOk.set_image(gtk.image_new_from_file("ok.png"))
    def createHelpButton(self):
        self.buttonHelp = hildon.Button(gtk.HILDON_SIZE_AUTO,  hildon.BUTTON_ARRANGEMENT_VERTICAL)        
        self.buttonHelp.connect("clicked", self.clickedHelp, self)
        self.box.add(self.buttonHelp)
        self.buttonHelp.set_image(gtk.image_new_from_file("help.png"))
    def createStatusLabel(self):
        self.label = gtk.Label("Hello World!!!")
        self.stage_title = gtk.Label("CAP STAGE 1")
        self.stage_title.show()
        self.label.show()
    def __init__(self):
        self.UIStep = True
        
        hildon.Program.__init__(self)
        
        pygame.mixer.init()
        pygame.init()
        self.sound1 = pygame.mixer.Sound("alarm.wav")
        self.sound1.set_volume(0.5)
        self.sound2 = pygame.mixer.Sound("alarm4.wav")
        self.sound3 = pygame.mixer.Sound("alarm3.wav")
        self.sound4 = pygame.mixer.Sound("alarm2.wav")
        self.sound_click = pygame.mixer.Sound("click.wav")
        
        self.sms_manager = Messager()   
        self.accel = Accelerometer()   
        self.window = hildon.Window()        
        self.window.connect("delete_event", self.quit)  
        self.add_window(self.window)
        self.STAGE = 1
        self.box = gtk.HButtonBox()
        self.box.set_layout(gtk.BUTTONBOX_EDGE)
                
        self.image = gtk.Image()
        self.image.set_from_file("ok.png")
        self.image.show()
        
        if (self.UIStep == True):
            self.createHelpButton()
            self.createStatusLabel()
            self.createOkButton()
            self.UIStep = False
        else:
            self.createOkButton()
            self.createStatusLabel()
            self.createHelpButton()
            self.UIStep = True        
        
        self.subbox = gtk.VButtonBox()
        self.subbox.set_layout(gtk.BUTTONBOX_EDGE)
        self.subbox.add(self.box)
        #self.subbox.add(self.stage_title)
        self.subbox.add(self.label)                  
        self.window.fullscreen()
        self.bus = dbus.SystemBus()
        self.csd_call = dbus.Interface(self.bus.get_object("com.nokia.csd",
                                                      "/com/nokia/csd/call"),
                                                      "com.nokia.csd.Call")   
        self.window.add(self.subbox)        
        self.time_stamp = time.time()
        self.SendSMS()
        self.previousReading = self.accel.getReadings()        
        self.currentReading = 0;
        self.window.hide()      
        
    def Call(self, number):
        self.csd_call.CreateWith(str(number), dbus.UInt32(0))
        
    def quit(self, *args):
        if (gtk.init_check()):
            gtk.main_quit()
    
    def SendSMS(self):
        self.sms_manager.Send("HELP! I'm in trouble!", "0451341363")  
    
    def waitForFall(self):
        while True:
            gtk.main_iteration_do(False)
            self.currentReading = self.previousReading - self.accel.getReadings()            
            self.previousReading = self.accel.getReadings()
            if (self.currentReading > 1300 or self.currentReading < -1300):
                break
        self.showWindow()
        
    def CheckTime(self, ttl):
        print str(ttl)
        if (time.time() > self.time_stamp + ttl):
            self.time_stamp = time.time()
            if (self.STAGE < 5):
                self.STAGE = self.STAGE + 1
                self.sound_click.play()
                self.PlayAlarm()
                if (self.STAGE == 4):
                    self.SendSMS()
                    #self.Call("0451341363")
                #elif (self.STAGE == 5):
                    #self.Call("112")    
        return int(ttl - ( time.time() - self.time_stamp))
      
    def PlayAlarm(self):
        
        if self.STAGE == 2:
            self.sound1.play(-1)
            self.sound2.stop()
            self.sound3.stop()
            self.sound4.stop()
        elif self.STAGE == 3:
            self.sound2.play(-1)
            self.sound1.stop()
            self.sound3.stop()
            self.sound4.stop()
        elif self.STAGE == 4:
            self.sound3.play(-1)
            self.sound1.stop()
            self.sound2.stop()
            self.sound4.stop()
        elif self.STAGE == 5:
            self.sound4.play(-1)
            self.sound1.stop()
            self.sound2.stop()
            self.sound3.stop()     

    def run(self):   
        while True:
            if self.STAGE == 1:                
                self.waitForFall()                
            elif self.STAGE == 2:
                self.label.set_markup("<big>\tCAP LEVEL " + str(self.STAGE) + "\nYou might have fall.\nConfirm you're ok!\nCAP alarm level 3 in " + str(self.CheckTime(40))+ " seconds</big>")
            elif self.STAGE == 3:                
                self.label.set_markup("<big>\tCAP LEVEL " + str(self.STAGE) + "\nI will play alarm sound\nConfirm you're ok!\nCAP alarm level 4 in " + str(self.CheckTime(40))+ " seconds</big>")
            elif self.STAGE == 4:
                self.label.set_markup("<big>\tCAP LEVEL " + str(self.STAGE) + "\nI will play alarm sound\nsend SMS and call for help.\nPlease, Confirm you're ok!\nCAP alarm level 5 in " + str(self.CheckTime(40))+ " seconds</big>")               
            elif self.STAGE == 5:                
                self.label.set_markup("<big>\tCAP LEVEL " + str(self.STAGE) + "\nI will play alarm sound\nand call 112.\n\nGood luck...</big>")                
            
            gtk.main_iteration_do(False)
            
if __name__ == "__main__":
    app = Cap()
    app.run()         





    